Installation
============

The Invenio Assets package is on PyPI so all you need is:

.. code-block:: console

    $ pip install invenio-assets

Invenio Asssets depends on Flask-Assets, WebAssets and Flask-Collect


Configuration
=============

* ``REQUIREJS_BASEURL``
* ``COLLECT_STATIC_ROOT``
